@@ -3,8 +3,11 @@ import numpy as np
 from metabolabpy.nmr import acqPars
 from metabolabpy.nmr import procPars
 from metabolabpy.nmr import dispPars
+from metabolabpy.nmr import splineBaseline
 import os
 from scipy.fftpack import fft, ifft, fftshift
+from scipy.interpolate import CubicSpline
+from scipy.interpolate import Rbf, InterpolatedUnivariateSpline
 import math
 import matplotlib.pyplot as pl
 from scipy import signal
@@ -53,6 +56,7 @@ class NmrData:
         self.acq = acqPars.AcqPars()
         self.proc = procPars.ProcPars()
         self.display = dispPars.DispPars()
+        self.spline_baseline = splineBaseline.SplineBaseline()
         self.fid_offset_corr = 0
         self.data_set_name = ''
         self.data_set_number = ''
@@ -158,6 +162,36 @@ class NmrData:
 
     # end add_hsqc_peak
 
+    def add_baseline_points(self):
+        if len(self.spline_baseline.baseline_points) == 0:
+            return
+
+        baseline_points = set(self.spline_baseline.baseline_points)
+        self.spline_baseline.baseline_points = list(baseline_points)
+        self.spline_baseline.baseline_points_pts = len(self.spc[0]) - self.ppm2points(self.spline_baseline.baseline_points)
+        outside_left = np.where(self.spline_baseline.baseline_points_pts < self.spline_baseline.average_points + 1)[0]
+        outside_right = np.where(self.spline_baseline.baseline_points_pts > len(self.spc[0]) - self.spline_baseline.average_points  - 1)[0]
+        for k in outside_left:
+            self.spline_baseline.baseline_points_pts[k] = self.spline_baseline.average_points + 1
+
+        for k in outside_right:
+            self.spline_baseline.baseline_points_pts[k] = len(self.spc[0]) - self.spline_baseline.average_points - 1
+
+        baseline_points = set(self.spline_baseline.baseline_points_pts)
+        self.spline_baseline.baseline_points_pts = list(baseline_points)
+        self.spline_baseline.baseline_points_pts.sort()
+        baseline_points = list(len(self.spc[0]) - np.array(self.spline_baseline.baseline_points_pts))
+        self.spline_baseline.baseline_points = self.points2ppm(baseline_points)
+        for k in range(len(self.spline_baseline.baseline_points)):
+            self.spline_baseline.baseline_points[k] = np.round( 1e4 * self.spline_baseline.baseline_points[k] ) / 1e4
+
+        self.spline_baseline.baseline_values = []
+        for k in self.spline_baseline.baseline_points_pts:
+            spc_points = np.linspace(k - self.spline_baseline.average_points, k + self.spline_baseline.average_points, 2*self.spline_baseline.average_points + 1, dtype=int)
+            self.spline_baseline.baseline_values.append(np.mean(self.spc[0][spc_points].real))
+
+        # end add_baseline_points
+
     def add_peak(self, start_end=np.array([], dtype='float64'), peak_label=''):
         if len(start_end) > 0:
             start_peak = int(1e4 * self.points2ppm(self.ppm2points(max(start_end), 0), 0)) / 1e4
@@ -1446,6 +1480,10 @@ class NmrData:
 
         # end read_spc
 
+    def set_spline_baseline(self):
+        print(a)
+        # end set_spline_baseline
+
     def set_ref(self, ref_shift, ref_point):
         for k in range(len(ref_shift)):
             self.ref_shift[k] = ref_shift[k]
@@ -1611,6 +1649,49 @@ class NmrData:
         #print("max_dist: {}, dist_2d: {}, cod1: {}, cod: {}".format(max_dist, dist_2d, cod1, self.hsqc.hsqc_data[self.hsqc.cur_metabolite].cod[self.hsqc.cur_peak - 1]))
         # end sim_hsqc_1d_calc_cod
 
+    def calc_spline_baseline(self):
+        baseline_points = []
+        baseline_points_pts = []
+        baseline_values = []
+        baseline_points.append(self.spline_baseline.baseline_points[0])
+        baseline_points_pts.append(self.spline_baseline.baseline_points_pts[0])
+        baseline_values.append(self.spline_baseline.baseline_values[0])
+        for k in range(len(self.spline_baseline.baseline_points_pts) - 1):
+            diff_pts = self.spline_baseline.baseline_points_pts[k+1] - self.spline_baseline.baseline_points_pts[k]
+            if diff_pts > self.spline_baseline.linear_spline:
+                n_pts = int(diff_pts / self.spline_baseline.linear_spline)
+                new_bsl = np.linspace(self.spline_baseline.baseline_points[k], self.spline_baseline.baseline_points[k+1], n_pts + 2)
+                new_bsl_pts = self.ppm2points(new_bsl)
+                new_bsl_vals = np.linspace(self.spline_baseline.baseline_values[k], self.spline_baseline.baseline_values[k+1], n_pts + 2)
+                for l in range(len(new_bsl) - 2):
+                    baseline_points.append(new_bsl[l + 1])
+                    baseline_points_pts.append(len(self.spc[0]) - new_bsl_pts[l+1])
+                    baseline_values.append(new_bsl_vals[l+1])
+
+            baseline_points.append(self.spline_baseline.baseline_points[k+1])
+            baseline_points_pts.append(self.spline_baseline.baseline_points_pts[k+1])
+            baseline_values.append(self.spline_baseline.baseline_values[k+1])
+
+        baseline_points.reverse()
+        baseline_values.reverse()
+        cs = CubicSpline(baseline_points, baseline_values,bc_type='natural')
+        #rbf = Rbf(baseline_points, baseline_values)
+        #ius = InterpolatedUnivariateSpline(baseline_points, baseline_values)
+        #baseline = ius(self.ppm1) #rbf(self.ppm1)
+        #baseline = rbf(self.ppm1)
+        baseline = cs(self.ppm1)
+        return baseline #baseline_points, baseline_values
+        # end calc_spline_baseline
+
+    def corr_spline_baseline(self):
+        self.add_baseline_points()
+        baseline = self.calc_spline_baseline()
+        spc1 = np.copy(self.spc[0])
+        spc1 -= baseline
+        self.spc[0] = np.copy(spc1)
+        self.add_baseline_points()
+        # end corr_spline_baseline
+
     def fit_hsqc_1d(self):
         autosim = self.hsqc.autosim
         self.hsqc.autosim = False
