@@ -20,7 +20,7 @@ import pandas as pd  # pragma: no cover
 class NmrDataSet:
 
     def __init__(self):
-        self.__version__ = '0.7.23'
+        self.__version__ = '0.8.01'
         self.nmrdat = [[]]
         self.s = 0
         self.e = -1
@@ -186,12 +186,12 @@ class NmrDataSet:
         return "Finished auto_ref"
         # end auto_ref
 
-    def auto_ref_all(self):
+    def auto_ref_all(self, tmsp=True):
         n_exp = len(self.nmrdat[self.s])
         orig_exp = self.e
         for k in range(n_exp):
             self.e = k
-            self.auto_ref()
+            self.auto_ref(tmsp)
 
         self.e = orig_exp
         return "Finished auto_ref_all"
@@ -263,6 +263,7 @@ class NmrDataSet:
             self.baseline1d_all()
             self.auto_ref_all()
             self.shift_ref()
+            self.spline_correct()
 
         else:
             s = self.s
@@ -1197,12 +1198,40 @@ class NmrDataSet:
 
     # end read_spcs
 
+    def reference1d_all(self, old_ppm=0.0, new_ppm=0.0):
+        s = self.s
+        for k in range(len(self.nmrdat[s])):
+            if self.nmrdat[s][k].dim != 1:
+                break
+
+            ref_point = len(self.nmrdat[s][k].spc[0]) - self.nmrdat[s][k].ppm2points(old_ppm) - 1
+            diff_pts = np.linspace(-1, 1, 3, dtype=int)
+            ref_pts = ref_point*np.ones(3, dtype=int) + diff_pts
+            found_maximum = False
+            while not found_maximum:
+                max_idx = np.where(self.nmrdat[s][k].spc[0][ref_pts] == np.max(self.nmrdat[s][k].spc[0][ref_pts]))[0][0]
+                ref_point += diff_pts[max_idx]
+                ref_pts = ref_point * np.ones(3, dtype=int) + diff_pts
+                if max_idx == 1:
+                    found_maximum = True
+
+            self.nmrdat[s][k].ref_point[0] = len(self.nmrdat[s][k].spc[0]) - ref_point - 1
+            self.nmrdat[s][k].ref_shift[0] = new_ppm
+            self.nmrdat[s][k].calc_ppm()
+        # end reference1d_all
+
     def reset_data_pre_processing(self):
         if not self.nmrdat[self.s][0].projected_j_res:
             self.ft_all()
             self.baseline1d_all()
             self.auto_ref_all()
             self.shift_ref()
+            if len(self.nmrdat[self.s][self.e].spline_baseline.baseline_points) > 0:
+                for k in range(len(self.nmrdat[self.s])):
+                    self.nmrdat[self.s][k].spline_baseline = self.nmrdat[self.s][self.e].spline_baseline
+                    self.nmrdat[self.s][k].add_baseline_points()
+                    self.nmrdat[self.s][k].corr_spline_baseline()
+
         else:
             s = self.s
             e = self.e
@@ -1589,6 +1618,12 @@ class NmrDataSet:
 
     # end shift_ref
 
+    def spline_correct(self):
+        if len(self.nmrdat[self.s][self.e].spline_baseline.baseline_points) > 0:
+            for k in range(len(self.nmrdat[self.s])):
+                self.nmrdat[self.s][k].spline_baseline.baseline_points = self.nmrdat[self.s][self.e].spline_baseline.baseline_points
+                self.nmrdat[self.s][k].corr_spline_baseline()
+
     def variance_stabilisation(self):
         if self.pp.auto_scaling:
             self.var_stab_auto_scale()
